import { createAsyncThunk } from '@reduxjs/toolkit';
import { get, post } from '../../services/api';
import { showNotification } from '../notification.slice';
import { logout } from './auth.slice';
import CryptoJS from 'crypto-js';

const secretKey = import.meta.env.VITE_SECRETKEY;

export const loginThunk = createAsyncThunk(
    'auth/login',
    async ({ username, password }, { rejectWithValue, dispatch }) => {
        try {
            const { message, data } = await post('/auth/login/', { username, password });
            if (!data) {
                throw new Error(message || 'Something went wrong');
            }
            const { token } = data;
            // encrypt token
            const encryptedToken = CryptoJS.AES.encrypt(token, secretKey).toString();
            sessionStorage.setItem('token', encryptedToken);

            return data;
        } catch (error) {
            const errorMessage = error.response?.data?.message || 'Something went wrong';
            dispatch(
                showNotification({
                    message: errorMessage,
                    type: 'danger',
                })
            );
            return rejectWithValue(errorMessage);
        }
    }
);

export const signupThunk = createAsyncThunk('auth/signup', async (config, { rejectWithValue, dispatch }) => {
    try {
        const { message, user } = await post('/signup', config);
        if (!user) {
            throw new Error(message || 'Something went wrong');
        }
        return user;
    } catch (error) {
        const errorMessage = error.response?.data?.message || 'Signup failed. Please try again.';
        dispatch(
            showNotification({
                message: errorMessage,
                type: 'danger',
            })
        );
        return rejectWithValue(errorMessage);
    }
});

export const checkAuthThunk = createAsyncThunk('auth/verify', async (_, { rejectWithValue, dispatch }) => {
    try {
        const { user, message } = await get('/auth/verify-token/');
        if (!user) {
            dispatch(logout());
            throw new Error(message || 'No token found');
        }
        return user;
    } catch (error) {
        dispatch(logout());
        return rejectWithValue(error.response?.data || 'Token verification failed');
    }
});

// Async thunk for logging out
export const logoutThunk = createAsyncThunk('auth/logout', async (_, { rejectWithValue, dispatch }) => {
    try {
        // Send the logout request to the server (this assumes your server clears any session-related info)
        await post('/auth/logout/');
        dispatch(logout());
    } catch (error) {
        const errorMessage = error.response?.data?.message || 'Log out failed';
        dispatch(
            showNotification({
                message: errorMessage,
                type: 'danger',
            })
        );
        return rejectWithValue(errorMessage);
    }
});
